@@ -261,7 +261,7 @@ void TorkUpdate::downloadComponent(TQString component, TQString version, TQStrin
                 KMessageBox::information (this,i18n( "<p><b>If this the first time you've compiled software then here are a few useful tips:</b><br>"
                     "1. Any error messages in the log file with the words 'TDE', 'TQt','curl' or 'X' in them mean that you need to install "
                     "the appropriate development libraries.<br>"
-                    "2. Any package provided by your distribution with 'lib' or 'devel' in the name is a development library, e.g. qt-devel, libkde.<br>"
+                    "2. Any package provided by your distribution with 'lib' or 'devel' in the name is a development library, e.g. tqt-devel, libtde.<br>"
                     "</p>" ),"Compilation Tips","compiler");
 
                  TQString command;
